
#!perl

# This file was automatically generated by Dist::Zilla::Plugin::Test::Map::Tube v0.36.

use strict; use warnings;
use utf8;
use Test::More;

my $min_tmt = '0.49';
eval "use Test::Map::Tube $min_tmt tests => 4";
plan skip_all => "Test::Map::Tube $min_tmt required" if $@;

use Map::Tube::Delhi;

my $map = new_ok('Map::Tube::Delhi');

SKIP: {

ok_map($map) or skip 'no map data found', 2;

ok_map_functions($map);

open(IN, '<:encoding(UTF-8)', "t/routes.txt") or die "Can't open routes file: $!\n"; my @routes = <IN>; close(IN);

ok_map_routes($map, \@routes);

}

